=========================
Probability Distributions
=========================

This package contains Gaussian and Binomial probability distributions.
Each distribution class has a few different simple methods.

Files:
=====
* README.md
* license.txt
* Binomialdistribution.py
* GaussianDistribution.py
* Generaldistribution.py

Installation:
============
pip install probability-distributions